# eric7.Preferences.ConfigurationPages.MainPasswordEntryDialog

Module implementing a dialog to enter or change the main password.

### Global Attributes

None

### Classes

MainPasswordEntryDialog | Class implementing a dialog to enter or change the main password.

### Functions

None

## MainPasswordEntryDialog

Class implementing a dialog to enter or change the main password.

### Derived from

QDialog, Ui_MainPasswordEntryDialog

### Class Attributes

None

### Class Methods

None

### Methods

MainPasswordEntryDialog | Constructor
__updateUI | Private slot to update the variable parts of the UI.
getCurrentPassword | Public method to get the current main password.
getMainPassword | Public method to get the new main password.
on_currentPasswordEdit_textChanged | Private slot to handle changes of the current password.
on_newPasswordAgainEdit_textChanged | Private slot to handle changes of the new again password.
on_newPasswordEdit_textChanged | Private slot to handle changes of the new password.

### Static Methods

None

#### MainPasswordEntryDialog (Constructor)

MainPasswordEntryDialog(oldPasswordHash, parent=None)

Constructor

oldPasswordHash (str)
  hash of the current password
parent (QWidget)
  reference to the parent widget

#### MainPasswordEntryDialog.__updateUI

__updateUI()

Private slot to update the variable parts of the UI.

#### MainPasswordEntryDialog.getCurrentPassword

getCurrentPassword()

Public method to get the current main password.

Return:
  current main password

Return Type:
  str

#### MainPasswordEntryDialog.getMainPassword

getMainPassword()

Public method to get the new main password.

Return:
  new main password

Return Type:
  str

#### MainPasswordEntryDialog.on_currentPasswordEdit_textChanged

on_currentPasswordEdit_textChanged(txt)

Private slot to handle changes of the current password.

txt (str)
  content of the edit widget

#### MainPasswordEntryDialog.on_newPasswordAgainEdit_textChanged

on_newPasswordAgainEdit_textChanged(txt)

Private slot to handle changes of the new again password.

txt (str)
  content of the edit widget

#### MainPasswordEntryDialog.on_newPasswordEdit_textChanged

on_newPasswordEdit_textChanged(txt)

Private slot to handle changes of the new password.

txt (str)
  content of the edit widget

Up